@@ -12,8 +12,6 @@
 ( cd opt/kde/share/doc/HTML/nl/kmoon ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kompare ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kompare ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
-( cd opt/kde/share/doc/HTML/nl/konsole ; rm -rf common )
-( cd opt/kde/share/doc/HTML/nl/konsole ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/khelpcenter/quickstart ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/khelpcenter/quickstart ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/khelpcenter ; rm -rf common )
